@@ -26,7 +26,8 @@
 // synthv1_ui - decl.
 //
 
-synthv1_ui::synthv1_ui ( synthv1 *pSynth ) : m_pSynth(pSynth)
+synthv1_ui::synthv1_ui ( synthv1 *pSynth, bool bPlugin )
+	: m_pSynth(pSynth), m_bPlugin(bPlugin)
 {
 }
 
@@ -37,6 +38,12 @@ synthv1 *synthv1_ui::instance (void) const
 }
 
 
+bool synthv1_ui::isPlugin (void) const
+{
+	return m_bPlugin;
+}
+
+
 void synthv1_ui::setParamValue ( synthv1::ParamIndex index, float fValue )
 {
 	m_pSynth->setParamValue(index, fValue);
