@@ -28,6 +28,9 @@
 #include "synthv1widget_config.h"
 #include "synthv1widget_control.h"
 
+#include "synthv1_controls.h"
+#include "synthv1_programs.h"
+
 #include <QMessageBox>
 #include <QDir>
 #include <QTimer>
@@ -210,6 +213,8 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	m_ui.Lfo1ResoKnob->setMaximum(+1.0f);
 	m_ui.Lfo1PitchKnob->setMinimum(-1.0f);
 	m_ui.Lfo1PitchKnob->setMaximum(+1.0f);
+	m_ui.Lfo1BalanceKnob->setMinimum(-1.0f);
+	m_ui.Lfo1BalanceKnob->setMaximum(+1.0f);
 	m_ui.Lfo1RingModKnob->setMinimum(-1.0f);
 	m_ui.Lfo1RingModKnob->setMaximum(+1.0f);
 	m_ui.Lfo1PanningKnob->setMinimum(-1.0f);
@@ -229,6 +234,8 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	m_ui.Lfo2ResoKnob->setMaximum(+1.0f);
 	m_ui.Lfo2PitchKnob->setMinimum(-1.0f);
 	m_ui.Lfo2PitchKnob->setMaximum(+1.0f);
+	m_ui.Lfo2BalanceKnob->setMinimum(-1.0f);
+	m_ui.Lfo2BalanceKnob->setMaximum(+1.0f);
 	m_ui.Lfo2RingModKnob->setMinimum(-1.0f);
 	m_ui.Lfo2RingModKnob->setMaximum(+1.0f);
 	m_ui.Lfo2PanningKnob->setMinimum(-1.0f);
@@ -390,6 +397,7 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	setParamKnob(synthv1::LFO1_CUTOFF,  m_ui.Lfo1CutoffKnob);
 	setParamKnob(synthv1::LFO1_RESO,    m_ui.Lfo1ResoKnob);
 	setParamKnob(synthv1::LFO1_PITCH,   m_ui.Lfo1PitchKnob);
+	setParamKnob(synthv1::LFO1_BALANCE, m_ui.Lfo1BalanceKnob);
 	setParamKnob(synthv1::LFO1_RINGMOD, m_ui.Lfo1RingModKnob);
 	setParamKnob(synthv1::LFO1_SWEEP,   m_ui.Lfo1SweepKnob);
 	setParamKnob(synthv1::LFO1_ATTACK,  m_ui.Lfo1AttackKnob);
@@ -601,6 +609,7 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	setParamKnob(synthv1::LFO2_CUTOFF,  m_ui.Lfo2CutoffKnob);
 	setParamKnob(synthv1::LFO2_RESO,    m_ui.Lfo2ResoKnob);
 	setParamKnob(synthv1::LFO2_PITCH,   m_ui.Lfo2PitchKnob);
+	setParamKnob(synthv1::LFO2_BALANCE, m_ui.Lfo2BalanceKnob);
 	setParamKnob(synthv1::LFO2_RINGMOD, m_ui.Lfo2RingModKnob);
 	setParamKnob(synthv1::LFO2_SWEEP,   m_ui.Lfo2SweepKnob);
 	setParamKnob(synthv1::LFO2_ATTACK,  m_ui.Lfo2AttackKnob);
@@ -1234,13 +1243,7 @@ void synthv1widget::helpConfigure (void)
 	if (pSynthUi == NULL)
 		return;
 
-	synthv1widget_config form(this);
-
-	// Set controllers&&programs database...
-	form.setControls(pSynthUi->controls());
-	form.setPrograms(pSynthUi->programs());
-
-	form.exec();
+	synthv1widget_config(pSynthUi, this).exec();
 }
 
 
