@@ -1,7 +1,7 @@
 // synthv1widget.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -50,8 +50,9 @@ public:
 	// Destructor.
 	virtual ~synthv1widget();
 
-	// Create/initialize the scheduler/work notifier.
-	void initSchedNotifier();
+	// Open/close the scheduler/work notifier.
+	void openSchedNotifier();
+	void closeSchedNotifier();
 
 	// Param port accessors.
 	void setParamValue(
@@ -59,8 +60,8 @@ public:
 	float paramValue(synthv1::ParamIndex index) const;
 
 	// Param kbob (widget) mapper.
-	void setParamKnob(synthv1::ParamIndex index, synthv1widget_knob *pKnob);
-	synthv1widget_knob *paramKnob(synthv1::ParamIndex index) const;
+	void setParamKnob(synthv1::ParamIndex index, synthv1widget_param *pKnob);
+	synthv1widget_param *paramKnob(synthv1::ParamIndex index) const;
 
 	// Preset init.
 	void initPreset();
@@ -93,6 +94,9 @@ protected slots:
 	// Schedule notification updater.
 	void updateSchedNotify(int stype, int sid);
 
+	// MIDI In LED timeout.
+	void midiInLedTimeout();
+
 	// Param knob context menu.
 	void paramContextMenu(const QPoint& pos);
 
@@ -132,6 +136,10 @@ protected:
 	// Dirty flag (overridable virtual) methods.
 	virtual void updateDirtyPreset(bool bDirtyPreset);
 
+	// Show/hide dget handlers.
+	void showEvent(QShowEvent *pShowEvent);
+	void hideEvent(QHideEvent *pHideEvent);
+
 private:
 
 	// Instance variables.
@@ -139,8 +147,8 @@ private:
 
 	synthv1widget_sched *m_sched_notifier;
 
-	QHash<synthv1::ParamIndex, synthv1widget_knob *> m_paramKnobs;
-	QHash<synthv1widget_knob *, synthv1::ParamIndex> m_knobParams;
+	QHash<synthv1::ParamIndex, synthv1widget_param *> m_paramKnobs;
+	QHash<synthv1widget_param *, synthv1::ParamIndex> m_knobParams;
 
 	float m_params_ab[synthv1::NUM_PARAMS];
 
