@@ -1,7 +1,7 @@
 // synthv1widget_preset.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -374,6 +374,7 @@ void synthv1widget_preset::resetPreset (void)
 	const QString& sPreset = m_pComboBox->currentText();
 	const bool bLoadPreset = (!sPreset.isEmpty()
 		&& m_pComboBox->findText(sPreset) >= 0);
+
 	if (bLoadPreset && !queryPreset())
 		return;
 
@@ -394,7 +395,9 @@ void synthv1widget_preset::refreshPreset (void)
 
 	const QString sOldPreset = m_pComboBox->currentText();
 	const QIcon icon(":/images/synthv1_preset.png");
+
 	m_pComboBox->clear();
+
 	synthv1_config *pConfig = synthv1_config::getInstance();
 	if (pConfig) {
 		QStringListIterator iter(pConfig->presetList());
@@ -451,9 +454,9 @@ void synthv1widget_preset::stabilizePreset (void)
 {
 	const QString& sPreset = m_pComboBox->currentText();
 
-	bool bEnabled = (!sPreset.isEmpty());
-	bool bExists  = (m_pComboBox->findText(sPreset) >= 0);
-	bool bDirty   = (m_iDirtyPreset > 0);
+	const bool bEnabled = (!sPreset.isEmpty());
+	const bool bExists  = (m_pComboBox->findText(sPreset) >= 0);
+	const bool bDirty   = (m_iDirtyPreset > 0);
 
 	m_pSaveButton->setEnabled(bEnabled && (!bExists || bDirty));
 	m_pDeleteButton->setEnabled(bEnabled && bExists);
